import React from 'react';
import ResultCtaButton from '../ResultCtaButton/ResultCtaButton';
export default function ResultCard(props) {
    const { result, addToCartCallback, clickItemCallback, salePriceKey, regularPriceKey } = props;
    const salePrice = salePriceKey && result?.data?.[salePriceKey];
    const regularPrice = regularPriceKey && result?.data?.[regularPriceKey];
    const clickHandler = () => {
        if (clickItemCallback && typeof clickItemCallback === 'function') {
            clickItemCallback(result);
        }
    };
    const keyDownHandler = (event) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            if (clickItemCallback && typeof clickItemCallback === 'function') {
                clickItemCallback(result);
            }
        }
    };
    const resultCardContent = () => (React.createElement(React.Fragment, null,
        React.createElement("div", { className: 'cio-result-card-image' },
            React.createElement("img", { src: result.data?.image_url, alt: 'product' })),
        React.createElement("div", { className: 'cio-result-card-text' },
            React.createElement("p", { className: 'cio-result-card-title' }, result.value),
            React.createElement("div", { className: 'cio-result-card-prices' },
                salePrice && React.createElement("span", { className: 'cio-result-card-sale-price' },
                    "$",
                    salePrice),
                regularPrice && (React.createElement("span", { className: `cio-result-card-regular-price${salePrice ? '--strike-through' : ''}` },
                    "$",
                    regularPrice)))),
        React.createElement(ResultCtaButton, { item: result, callback: addToCartCallback })));
    if (clickItemCallback) {
        return (React.createElement("div", { onClick: clickHandler, onKeyDown: keyDownHandler, className: 'cio-result-card', role: 'button', tabIndex: 0 }, resultCardContent()));
    }
    return (React.createElement("div", { className: 'cio-result-card' },
        React.createElement("a", { className: 'cio-result-card-anchor', href: result.data?.url }, resultCardContent())));
}
